###
### Rules.make -- General Rules for making Tunes -- -*-Makefile-*-
###

# Rules.make,v 1.2 2000/02/10 15:04:31 fare Exp

############################### FIRST GOAL ##################################

ifdef REQUIRE_CONFIG
ifeq ($(TUNES)/config.sh, $(wildcard $(TUNES)/config.sh))
include $(TUNES)/config.sh
else
ifndef CONFIGURATION
CONFIGURATION = config
endif
endif
endif

ifdef REQUIRE_DEPEND
ifneq ($(TUNES)/.depend, $(wildcard $(TUNES)/.depend))
ifndef CONFIGURATION
CONFIGURATION = depend
endif
endif
endif

ifdef GOAL
ifndef CONFIGURATION
CONFIGURATION = $(GOAL)
endif
endif

ifdef CONFIGURATION
all: $(CONFIGURATION)
endif

################################ INCLUDES ###################################

ifdef REQUIRE_CONFIG
ifeq ($(TUNES)/config.sh, $(wildcard $(TUNES)/config.sh))
include $(TUNES)/config.sh
endif
endif

ifdef REQUIRE_DEPEND
ifeq (.depend,$(wildcard .depend))
include .depend
endif
endif


# Ensure there's some rule at all
real_phony:


######################### Default values for commands #######################

ifndef SCHEME
SCHEME = guile
SCHEME_TYPE = guile
SCHEME_FLAGS = -s
endif

ifndef CC
CC	= gcc			# Use "cc" if you don't have gcc
endif

ifndef CFLAGS
CFLAGS = -O2 -fasm -fomit-frame-pointer -Wall
endif

ifndef CPP
CPP	= gcc -E		# may be "cpp" (perhaps "/lib/cpp")
endif

ifndef LD
LD	= ld
endif

ifndef PERL
PERL = perl
endif

ifndef INSTALL_BIN
INSTALL_BIN="install -s -m 755"
endif

ifndef INSTALL_DIR
INSTALL_DIR="install -d -m 755"
endif

ifndef RM
RM = rm -f
endif

ifndef MV
MV	= mv
endif

ifndef CP
CP	= cp
endif

ifndef CHMOD
CHMOD	= chmod
endif

ifndef COMPRESS
COMPRESS = gzip -f9		# Go get gzip if you don't have it yet
COMPRSUFFIX = .gz
endif

ifndef ARCHIVETYPE
ARCHIVETYPE=tgz
endif

ifndef ZSHELL
ZSHELL = zsh -f
endif

ifndef SHELL
SHELL	= $(ZSHELL) -y
#SHELL	= /bin/sh
endif

ifndef ARCH
ARCH = `uname -m`
endif

ifndef CONFIG
CONFIG=linux-i386
endif

INSTTOOL = $(TUNES)/bin/$(ARCH)/tunesinsttool
SCHEME_LIB_PATH = $(TUNES)/src/HLL/scm
BUILD = $(ZSHELL) $(TUNES)/build.zsh
DEST_DIR = $(TUNES)/bin/$(ARCH)

export TUNES
export ZSHELL SHELL RM CP LN MV
export COMPRESS COMPRSUFFIX ARCHIVETYPE PATCH_PREFIX

############################ Rules proper ###################################

.PHONY:		phony real_phony all config autoconf dep depend wdep wdepend \
		Tunes test install clean veryclean mrproper tgz tar \
		bin binaries doc documentation both \
		%.foo

.SUFFIXES:	.hlm .scm .v .scm .ml .mli .m4 .S .c .h \
		.sgml .tex .html .txt .bib \
		.dvi .ps .x .vo .zo .zi .za .i .s .o .a .b \
		.log .aux .bbl .toc .bst .foo

%.html:	%.sgml
	sgml2html -c latin $*

%.txt:	%.sgml
	sgml2txt -c latin $*

%.aux %.toc:  %.tex
	latex $*

%.bbl %.blg:  %.toc %.tex
	bibtex $*

%.dvi:	%.tex # %.bbl
	latex $*

%.ps:   %.dvi
	dvips -o $@ $<

%.x:	%.dvi phony
	xdvi $<

%.vo:	%.v
	coqc $<

%.s:	%.c
	$(CC) $(CFLAGS) -S -fverbose-asm -fasm -o $@ $<

%.o:	%.c
	$(CC) $(CFLAGS) -c -o $@ $<

#%.o:	%.s
#	$(AS) $(ASFLAGS) -o $@ $<

%.b:	%.o
	$(CC) $(LDFLAGS) -o $@ $<

%.foo::	%
	@: Phony command...

############################ CONFIGURATION ###################################

configuration: $(CONFIGURATION) $(TUNES)/config.sh

autoconf: $(TUNES)/autoconf.zsh
	$(ZSHELL) $(TUNES)/autoconf.zsh

config: autoconf

depend:	$(TUNES)/config.sh $(TUNES)/build.zsh
	$(BUILD) depend > .depend

wdepend: $(TUNES)/config.sh $(TUNES)/build.zsh
	$(BUILD) wdepend

clean:
	$(BUILD) clean

veryclean:
	$(BUILD) veryclean

mrproper:
	$(BUILD) mrproper

dep: depend
wdep: wdepend
doc: documentation
bin: binaries
